@@ -1,15 +1,19 @@
-from unittest import TestCase
-from trac.test  import EnvironmentStub
+import unittest
+from trac.test import EnvironmentStub
+from simplemultiproject.environmentSetup import smpEnvironmentSetupParticipant
 from simplemultiproject.smp_model import SmpMilestone
+from simplemultiproject.tests.util import revert_schema
 
 __author__ = 'cinc'
 
 
-class TestSmpMilestone(TestCase):
+class TestSmpMilestone(unittest.TestCase):
 
     def setUp(self):
         self.env = EnvironmentStub(default_data=True, enable=["trac.*", "simplemultiproject.*"])
-        self.env.upgrade()
+        with self.env.db_transaction as db:
+            revert_schema(self.env)
+            smpEnvironmentSetupParticipant(self.env).upgrade_environment(db)
         # self.env.config.set("ticket-custom", "project", "select")
         self.model = SmpMilestone(self.env)
         self.model.add("foo1", 1)
@@ -17,6 +21,9 @@ class TestSmpMilestone(TestCase):
         self.model.add("baz", 3)
         self.model.add("foo2", 1)
 
+    def tearDown(self):
+        self.env.reset_db()
+
     def test_delete(self):
         self.assertEqual(4, len(self.model.get_all_milestones_and_id_project_id()))
         self.model.delete("baz")
@@ -33,3 +40,13 @@ class TestSmpMilestone(TestCase):
         self.assertEqual(2, len(items))
         self.assertEqual("foo1", items[0])
         self.assertEqual("foo2", items[1])
+
+
+def suite():
+    suite = unittest.TestSuite()
+    suite.addTest(unittest.makeSuite(TestSmpMilestone))
+    return suite
+
+
+if __name__ == '__main__':
+    unittest.main(defaultTest='suite')
