@@ -34,23 +34,27 @@ class SmpTimelineProjectFilter(Component):
 
     def post_process_request(self, req, template, data, content_type):
         path_elms = req.path_info.split('/')
-        if data and path_elms[1] == 'timeline':
+        if data and len(path_elms) > 1 and path_elms[1] == 'timeline':
             # These are the defined events for the ticket subsystem
             ticket_kinds = ['newticket', 'closedticket', 'reopenedticket', 'editedticket', 'attachment']
             proj_filter = get_project_filter_settings(req, 'timeline', 'smp_projects', 'All')  # This returns a list of names
             filtered_events = []
 
             for event in data.get('events'):
-                resource = event['data'][0].parent if event['kind'] == 'attachment' else event['data'][0]
-                if event['kind'] in ticket_kinds and 'All' not in proj_filter and resource.realm == 'ticket':
-                    # We have some ticket event, maybe attachment to ticket
-                    tkt = Ticket(self.env, resource.id)
-                    if tkt['project'] in proj_filter:
-                        # New render function enhancing the title
-                        event['render'] = self._lambda_render_func(tkt['project'], event['render'])
-                        filtered_events.append(event)
+                if event['kind'] in ticket_kinds:
+                    resource = event['data'][0].parent if event['kind'] == 'attachment' else event['data'][0]
+                    if event['kind'] in ticket_kinds and 'All' not in proj_filter and resource.realm == 'ticket':
+                        # We have some ticket event, maybe attachment to ticket
+                        tkt = Ticket(self.env, resource.id)
+                        if tkt['project'] in proj_filter:
+                            # New render function enhancing the title
+                            event['render'] = self._lambda_render_func(tkt['project'], event['render'])
+                            filtered_events.append(event)
+                    else:
+                        filtered_events.append(event)  # Show this event
                 else:
                     filtered_events.append(event)  # Show this event
+
             data['events'] = filtered_events
 
         return template, data, content_type
@@ -59,7 +63,7 @@ class SmpTimelineProjectFilter(Component):
 
     def filter_stream(self, req, method, filename, stream, data):
         path_elms = req.path_info.split('/')
-        if path_elms[1] == 'timeline':
+        if len(path_elms) > 1 and path_elms[1] == 'timeline':
             # Add project selection to the roadmap preferences
             xformer = Transformer('//form[@id="prefs"]')
             stream = stream | xformer.prepend(create_proj_table(self, self._SmpModel, req))
